#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['yaqd_lightcon']

package_data = \
{'': ['*']}

install_requires = \
['yaqd-core>=2020.10.1', 'aiohttp']

extras_require = \
{'dev': ['black', 'pre-commit']}

entry_points = \
{'console_scripts': ['yaqd-lightcon-topas4-motor = '
                     'yaqd_lightcon._lightcon_topas4_motor:LightconTopas4Motor.main',
                     'yaqd-lightcon-topas4-shutter = '
                     'yaqd_lightcon._lightcon_topas4_shutter:LightconTopas4Shutter.main']}

setup(name='yaqd-lightcon',
      version='2021.10.0',
      description='yaq daemons for hardware from Light Conversion',
      author='yaq Developers',
      author_email='git@ksunden.space',
      url='https://yaq.fyi',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )



import asyncio
import pathlib
from typing import Dict, Any, List

import aiohttp  # type: ignore
from yaqd_core import IsHomeable, IsDiscrete, HasLimits, HasPosition, IsDaemon


class LightconTopas4Motor(IsHomeable, IsDiscrete, HasLimits, HasPosition, IsDaemon):
    _kind = "lightcon-topas4-motor"

    def __init__(self, name: str, config: Dict[str, Any], config_filepath: pathlib.Path):
        super().__init__(name, config, config_filepath)
        self._base_url = f"http://{config['topas4_host']}:{config['topas4_port']}/{config['serial']}/v0/PublicApi"
        self._motor_index = config["motor_index"]
        self._http_session = aiohttp.ClientSession()
        self._position_identifiers: Dict[str, float] = {}

    async def update_state(self):
        while True:
            async with self._http_session.get(
                f"{self._base_url}/Motors?id={self._motor_index}"
            ) as resp:
                json = await resp.json()
                self._state["position"] = json["ActualPositionInUnits"]
                self._state["hw_limits"] = (
                    json["MinimalPositionInUnits"],
                    json["MaximalPositionInUnits"],
                )

                self._units = json["UnitName"]

                offset = json["Affix"]
                scale = json["Factor"]

                self._position_identifiers: Dict[str, float] = {
                    i["Name"]: i["Position"] / 8 / scale + offset for i in json["NamedPositions"]
                }

                self._busy = (
                    json["ActualPosition"] != json["TargetPosition"]
                    or abs(json["TargetPositionInUnits"] - self._state["destination"]) > 0.01
                    or json["IsHoming"]
                )

                for i, val in self._position_identifiers.items():
                    if self._state["position"] - val < 0.01:
                        self._state["position_identifier"] = i
                        break
                else:
                    self._state["position_identifier"] = None

            if not self._busy:
                await self._busy_sig.wait()
            else:
                await asyncio.sleep(0.01)

    def _set_position(self, position):
        self._busy = True
        self._loop.create_task(
            self._http_session.put(
                f"{self._base_url}/Motors/TargetPositionInUnits?id={self._motor_index}",
                json=position,
            )
        )

    def home(self):
        self._busy = True
        self._loop.create_task(
            self._http_session.post(f"{self._base_url}/Motors/Home?id={self._motor_index}")
        )



import asyncio
import pathlib
from typing import Dict, Any, List

import aiohttp  # type: ignore
from yaqd_core import IsDiscrete, IsDaemon


class LightconTopas4Shutter(IsDiscrete, IsDaemon):
    _kind = "lightcon-topas4-shutter"

    def __init__(self, name: str, config: Dict[str, Any], config_filepath: pathlib.Path):
        super().__init__(name, config, config_filepath)
        self._base_url = f"http://{config['topas4_host']}:{config['topas4_port']}/{config['serial']}/v0/PublicApi"
        self._http_session = aiohttp.ClientSession()

    async def update_state(self):
        while True:
            async with self._http_session.get(
                f"{self._base_url}/ShutterInterlock/IsShutterOpen"
            ) as resp:
                try:
                    self._state["position"] = await resp.json()
                    self._state["position_identifier"] = (
                        "open" if self._state["position"] else "closed"
                    )
                except:
                    self.logger.error(await resp.read())
            self._busy = bool(self._state["position"]) != bool(self._state["destination"])
            if not self._busy:
                await self._busy_sig.wait()
            else:
                await asyncio.sleep(0.01)

    def _set_position(self, position):
        self._busy = True
        self._loop.create_task(
            self._http_session.put(
                f"{self._base_url}/ShutterInterlock/OpenCloseShutter", json=bool(position)
            )
        )
